/*=============================================================================
	Vertexshader for DrawComplexSurface, single pass.

	Revision history:
		* Created by Smirftsch
=============================================================================*/

layout (location = 0) in vec3 Coords;		// == gl_Vertex
layout (location = 1) in vec3 Normals;
layout (location = 2) in vec2 TexCoords;
layout (location = 3) in vec2 LightMapCoords;
layout (location = 5) in vec2 DetailTexCoords;
layout (location = 6) in vec2 MacroTexCoords;
layout (location = 7) in vec2 BumpTexCoords;

layout(std140) uniform GlobalMatrices
{
	mat4 modelviewprojMat;
	mat4 modelviewMat;
};

uniform vec4 LightPos[8];

out vec4 vEyeSpacePos;
out vec2 vTexCoords;
out vec2 vLightMapCoords;
out vec2 vDetailTexCoords;
out vec2 vMacroTexCoords;
out vec2 vBumpTexCoords;
out vec3 vCoords;
out vec3 vNormals;
out vec4 vLightPos[8];

void main(void)
{
	vec4 vEyeSpacePosVertex = modelviewMat*vec4(Coords, 1.0);
	vEyeSpacePos = vEyeSpacePosVertex;

	// Point Coords
	vCoords = Coords;

	//Texture UV to fragment
	vTexCoords=TexCoords;

	//Texture UV Lightmap to fragment
	vLightMapCoords	= LightMapCoords;

	// Texture UV DetailTexture
	vDetailTexCoords = DetailTexCoords;

	// Texture UV Macrotexture
	vMacroTexCoords = MacroTexCoords;

	// Texture UV BumpMap
	vBumpTexCoords = BumpTexCoords;
	for( int i=0; i<8; ++i)
	{
		//Set the lightposition
		vLightPos[i] = normalize(LightPos[i]*modelviewMat); 
	}

	// Normals
	vNormals = Normals;

	gl_Position = modelviewprojMat * vec4(Coords, 1.0);
}
