/*=============================================================================
	Fragmentshader for DrawTile.

	Revision history:
		* Created by Smirftsch
=============================================================================*/

uniform sampler2D Texture0;
uniform vec4 DrawColor;
uniform uint PolyFlags;
uniform float Gamma;

in vec2 vTexCoords;
in vec4 vDrawColor;

out vec4 FragColor;

void main(void)
{
	vec4 TotalColor;
	vec4 Color = texture(Texture0, vTexCoords);

	// Handle PF_Masked.
	if ( (PolyFlags&PF_Masked) == PF_Masked )
	{
		if(Color.a < 0.5)
			discard;
		else Color.rgb /= Color.a;
	}
	else if ( (PolyFlags&PF_AlphaBlend) == PF_AlphaBlend && Color.a < 0.01 )
		discard;

	// Editor support.
	if ( (PolyFlags&PF_Selected) == PF_Selected )
	{
		Color.r *= 0.125 + 0.1;
		Color.g *= 0.125 + 0.1;
		Color.b = (Color.b*0.125) + 0.5;
		Color = clamp(Color,0.0,1.0);
	}

	TotalColor = Color * vDrawColor; // Add DrawColor.

	if((PolyFlags & PF_Modulated)!=PF_Modulated)
	{
		// Gamma
		TotalColor.r=pow(TotalColor.r,2.0-Gamma);
		TotalColor.g=pow(TotalColor.g,2.0-Gamma);
		TotalColor.b=pow(TotalColor.b,2.0-Gamma);
	}

	// Mostly for UED here. HitSelection, Zoneview etc.
	if (DrawColor != 0.0)
		TotalColor = DrawColor; // Use DrawColor.

	FragColor = TotalColor;
}
